aboutsummaryrefslogtreecommitdiff
path: root/discord/member.py
diff options
context:
space:
mode:
authorRapptz <[email protected]>2020-01-14 20:54:31 -0500
committerRapptz <[email protected]>2020-01-14 20:56:00 -0500
commit42a084028ce38c35285efa48edff3425bbd06e5e (patch)
treed0aeeea37b82be0f10ae599a3091edfd346bab12 /discord/member.py
parentAdd support for custom activities (diff)
downloaddiscord.py-42a084028ce38c35285efa48edff3425bbd06e5e.tar.xz
discord.py-42a084028ce38c35285efa48edff3425bbd06e5e.zip
Expose _ActivityTag as BaseActivity to easily refer to.
Diffstat (limited to 'discord/member.py')
-rw-r--r--discord/member.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/discord/member.py b/discord/member.py
index 70acedd6..42976a91 100644
--- a/discord/member.py
+++ b/discord/member.py
@@ -150,7 +150,7 @@ class Member(discord.abc.Messageable, _BaseUser):
joined_at: Optional[:class:`datetime.datetime`]
A datetime object that specifies the date and time in UTC that the member joined the guild for
the first time. In certain cases, this can be ``None``.
- activities: Tuple[Union[:class:`Game`, :class:`Streaming`, :class:`Spotify`, :class:`Activity`]]
+ activities: Tuple[Union[:class:`BaseActivity`, :class:`Spotify`]]
The activities that the user is currently doing.
guild: :class:`Guild`
The guild that the member belongs to.
@@ -381,7 +381,7 @@ class Member(discord.abc.Messageable, _BaseUser):
@property
def activity(self):
"""Union[:class:`Game`, :class:`Streaming`, :class:`Spotify`, :class:`Activity`]: Returns the primary
activity the user is currently doing. Could be None if no activity is being done.
.. note::
@@ -381,7 +381,7 @@ class Member(discord.abc.Messageable, _BaseUser):
def activity(self):
- """Union[:class:`Game`, :class:`Streaming`, :class:`Spotify`, :class:`Activity`]: Returns the primary
+ """Union[:class:`BaseActivity`, :class:`Spotify`]: Returns the primary
activity the user is currently doing. Could be None if no activity is being done.
.. note::